# History of changes

## Version 0.5 (2020/03/14)

### Issues Closed

#### Features

* [Issue 111](https://github.com/spyder-ide/loghub/issues/111) - Add configuration file ([PR 114](https://github.com/spyder-ide/loghub/pull/114) by [@goanpeca](https://github.com/goanpeca))

#### Enhancements

* [Issue 102](https://github.com/spyder-ide/loghub/issues/102) - Add support for zenhub releases (when used instead of milestones) ([PR 106](https://github.com/spyder-ide/loghub/pull/106) by [@goanpeca](https://github.com/goanpeca))
* [Issue 95](https://github.com/spyder-ide/loghub/issues/95) - Add user to rendered changelog ([PR 110](https://github.com/spyder-ide/loghub/pull/110) by [@goanpeca](https://github.com/goanpeca))
* [Issue 93](https://github.com/spyder-ide/loghub/issues/93) - Add option to disable related issues and PRs ([PR 108](https://github.com/spyder-ide/loghub/pull/108) by [@goanpeca](https://github.com/goanpeca))

#### Bugs fixed

* [Issue 94](https://github.com/spyder-ide/loghub/issues/94) - ApiNotFoundError ([PR 109](https://github.com/spyder-ide/loghub/pull/109) by [@goanpeca](https://github.com/goanpeca))

In this release 5 issues were closed.

## Version 0.4 (2018/08/09)

### Issues Closed

#### Enhancements

* [Issue 90](https://github.com/spyder-ide/loghub/issues/90) - Add ability to group pull requests by labels ([PR 92](https://github.com/spyder-ide/loghub/pull/92))

In this release 1 issue was closed.

----

## Version 0.3.3 (2018-02-20)

### Issues Closed

#### Bugs fixed

* [Issue 89](https://github.com/spyder-ide/loghub/issues/89) - Batch processing breaks on python 3 ([PR 91](https://github.com/spyder-ide/loghub/pull/91))

In this release 1 issue was closed.

----

## Version 0.3.2 (2018-02-18)

### Issues Closed

#### Bugs fixed

* [Issue 88](https://github.com/spyder-ide/loghub/issues/88) - Repo name is incorrectly detected from pull request body ([PR 86](https://github.com/spyder-ide/loghub/pull/86))

In this release 1 issue was closed.

----

## Version 0.3.1 (2018-02-16)

### Issues Closed

#### Enhancements

* [Issue 72](https://github.com/spyder-ide/loghub/issues/72) - Output examples

#### Bugs fixed

* [Issue 81](https://github.com/spyder-ide/loghub/issues/81) - `None` issue number causing TypeError ([PR 83](https://github.com/spyder-ide/loghub/pull/83))
* [Issue 78](https://github.com/spyder-ide/loghub/issues/78) - Avoid crash with empty body ([PR 76](https://github.com/spyder-ide/loghub/pull/76))
* [Issue 75](https://github.com/spyder-ide/loghub/issues/75) - Bug: No issues found for -ilg group creates error ([PR 76](https://github.com/spyder-ide/loghub/pull/76))

In this release 4 issues were closed.

----

## Version 0.3 (2017-10-10)

### Issues Closed

#### Enhancements

* [Issue 63](https://github.com/spyder-ide/loghub/issues/63) - Add PR link / commit link inside issue ([PR 69](https://github.com/spyder-ide/loghub/pull/69))

In this release 1 issue was closed.

----

## Version 0.2.1 (2017-10-10)

### Issues Closed

#### Bugs fixed

* [Issue 67](https://github.com/spyder-ide/loghub/issues/67) - Templates not included in pip package ([PR 68](https://github.com/spyder-ide/loghub/pull/68))

In this release 1 issue was closed.

----

## Version 0.2 (2017-02-01)

### Issues Closed

#### Features 

* [Issue 46](https://github.com/spyder-ide/loghub/issues/46) - Create labels automagically on github based on template ([PR 59](https://github.com/spyder-ide/loghub/pull/59))
* [Issue 30](https://github.com/spyder-ide/loghub/issues/30) - Add label groupings ([PR 34](https://github.com/spyder-ide/loghub/pull/34))
* [Issue 28](https://github.com/spyder-ide/loghub/issues/28) - Generate all changelog based on tags ([PR 61](https://github.com/spyder-ide/loghub/pull/61))
* [Issue 27](https://github.com/spyder-ide/loghub/issues/27) - Generate all changelog based on milestones ([PR 61](https://github.com/spyder-ide/loghub/pull/61))
* [Issue 21](https://github.com/spyder-ide/loghub/issues/21) - Add branch parameter to select PRs to display based on the merging branch ([PR 32](https://github.com/spyder-ide/loghub/pull/32))
* [Issue 10](https://github.com/spyder-ide/loghub/issues/10) - Support custom line formats [templates] ([PR 20](https://github.com/spyder-ide/loghub/pull/20))
* [Issue 4](https://github.com/spyder-ide/loghub/issues/4) - Expose labels for additional filtering ([PR 17](https://github.com/spyder-ide/loghub/pull/17))
* [Issue 3](https://github.com/spyder-ide/loghub/issues/3) - Add access token interface ([PR 18](https://github.com/spyder-ide/loghub/pull/18))

#### Enhancements

* [Issue 57](https://github.com/spyder-ide/loghub/issues/57) - Allow Enable/Disable of PR output ([PR 65](https://github.com/spyder-ide/loghub/pull/65))
* [Issue 41](https://github.com/spyder-ide/loghub/issues/41) - Add default template for release with issue label grouping ([PR 43](https://github.com/spyder-ide/loghub/pull/43))
* [Issue 40](https://github.com/spyder-ide/loghub/issues/40) - Provide available milestones to user when provided not found ([PR 44](https://github.com/spyder-ide/loghub/pull/44))
* [Issue 16](https://github.com/spyder-ide/loghub/issues/16) - Better authorization handling  ([PR 44](https://github.com/spyder-ide/loghub/pull/44))
* [Issue 11](https://github.com/spyder-ide/loghub/issues/11) - Support hidden password ([PR 14](https://github.com/spyder-ide/loghub/pull/14))
* [Issue 8](https://github.com/spyder-ide/loghub/issues/8) - Support "all issues"  ([PR 19](https://github.com/spyder-ide/loghub/pull/19))

#### Bugs fixed

* [Issue 56](https://github.com/spyder-ide/loghub/issues/56) - Fix output for grouped labels if no items on that group ([PR 58](https://github.com/spyder-ide/loghub/pull/58))
* [Issue 55](https://github.com/spyder-ide/loghub/issues/55) - Fix date on generation based on milestone ([PR 58](https://github.com/spyder-ide/loghub/pull/58))
* [Issue 15](https://github.com/spyder-ide/loghub/issues/15) - Since tag not working properly ([PR 13](https://github.com/spyder-ide/loghub/pull/13))

In this release 17 issues were closed.

----

## Version 0.1.2 (2016/11/22)

### Bugs fixed

**Pull requests**

* [PR 12](https://github.com/spyder-ide/loghub/pull/12) - Don't test macOS in Travis
* [PR 9](https://github.com/spyder-ide/loghub/pull/9) - Don't show "Issues" or "Pull requests" sections if there are no issues or PRs to show
* [PR 7](https://github.com/spyder-ide/loghub/pull/7) - Fix contents of temporary file
* [PR 6](https://github.com/spyder-ide/loghub/pull/6) - Remove extra empty lines
* [PR 5](https://github.com/spyder-ide/loghub/pull/5) - Fix PR_SHORT formatting.

In this release 5 pull requests were merged

----

## Version 0.1.0

* Initial release
